@@ -5,6 +5,7 @@
 #' Via http://stackoverflow.com/questions/2547402/is-there-a-built-in-function-for-finding-the-mode
 #'
 #' @param x vector
+#' @param exclude_na Exclude NA from being a possible mode.
 #'
 #' @return Vector of modal values in arbitrary order.
 #'
@@ -19,8 +20,13 @@
 #' Mode(Boston$chas)
 #'
 #' @export
-Mode = function(x) {
+Mode = function(x, exclude_na = TRUE) {
   ux = unique(x)
+
+  if (exclude_na) {
+    ux = setdiff(ux, NA)
+  }
+
   tab = tabulate(match(x, ux))
   # This will return multiple modes if they exist.
   ux[tab == max(tab)]
