@@ -1,6 +1,11 @@
 library(ck37r)
 library(SuperLearner)
-library(testthat)
+
+# Only run test if necessary suggested packages are installed.
+pkg_suggests = c("testthat", "MASS")
+if (!all(suppressWarnings(sapply(pkg_suggests, require, quietly = TRUE,
+                                 character.only = TRUE))))
+  return()
 
 context("CVSL auc")
 
@@ -22,3 +27,4 @@ cvsl = CV.SuperLearner(Boston$chas, X[, 1:3], family = binomial(),
 cvsl_auc(cvsl)
 
 # TODO: cause an error in cvAUC::ci.cvAUC for testing purposes.
+
